trainer.Serializer
==================

.. currentmodule:: trainer

.. autoclass:: Serializer

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Serializer.__init__
      ~Serializer.serialize
      ~Serializer.serialize_inv
   
   

   
   
   